pub struct Border { /* private fields */ }Expand description
Draw a border around an element.
The border will size it self around the child if it has one.
If a width and / or a height is provided then the border will produce tight constraints for the child.
If a border has no size (width and height) and no child then nothing will be rendered.
To render a border with no child provide a width and a height.