Text

Struct Text 

pub struct Text { /* private fields */ }
Text widget

Attributes:
* background
* foreground
* text-align
* wrap

Note: Spans, unlike other widgets, does not require a widget id

A Text widget will be as wide as its text.