pub struct Text { /* private fields */ }Expand description
Text widget
ⓘ
Attributes:
* background
* foreground
* text-align
* wrapNote: Spans, unlike other widgets, does not require a widget id
A Text widget will be as wide as its text.